<?php
/**
 * Plugin Name:       Custom Stock Status
 * Plugin URI:        https://woocommerce.com/products/custom-stock-status/
 * Description:       Display custom stock statuses to communicate precise information about your stock availability.
 * Version:           1.2.4
 * Author:            Addify
 * Developed By:      Addify
 * Author URI:        https://woocommerce.com/vendor/addify/
 * Support:           https://woocommerce.com/vendor/addify/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Domain Path:       /languages
 * Text Domain:       addify_css
 * WC requires at least: 3.0.9
 * WC tested up to: 7.*.*
 * Woo: 7512757:043fd333531476b6ed47e9001ca0d132
 *
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; 
}
if ( ! is_multisite() ) {

	if ( ! in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ), true ) ) {
		function acss_admin_notice() {

			deactivate_plugins( __FILE__ );

			$acss_woo_check = '<div id="message" class="error">
				<p><strong>' . __( 'Custom Stock Status plugin is inactive.', 'addify_as' ) . '</strong> The <a href="http://wordpress.org/extend/plugins/woocommerce/">WooCommerce plugin</a> ' . __( 'must be active for this plugin to work. Please install &amp; activate WooCommerce.', 'addify_css' ) . ' »</p></div>';
			echo wp_kses_post( $acss_woo_check );

		}
		add_action( 'admin_notices', 'acss_admin_notice' );
	}
}
if ( ! class_exists( 'Custom_Stock_Status' ) ) {

	class Custom_Stock_Status {

		public function __construct() {

			register_activation_hook( __FILE__, array( $this, 'default_settings' ) );

			$this->a_c_s_s_global_constants_vars();

			add_action( 'init', array( $this, 'acss_register_post_type' ) );

			add_action( 'wp_loaded', array( $this, 'a_c_s_s_load_text_domain' ) );

			add_action( 'wp_ajax_acss_custom_stock_status', array( $this, 'acss_custom_stock_status' ) );

			add_action( 'wp_ajax_delete_custom_stock_status', array( $this, 'delete_custom_stock_status' ) );

			if ( is_admin() ) {

				include_once ACSS_PLUGIN_DIR . '/includes/class-af-c-s-s-admin.php';

			} else {

				include_once ACSS_PLUGIN_DIR . '/includes/class-af-c-s-s-front.php';

			}
		}

		public function default_settings() {
			$default_enable_pro_page     = get_option( 'acss_default_stock_enable_pro_page' );
			$default_enable              = get_option( 'acss_default_stock_enable' );
			$multiple_enable             = get_option( 'acss_show_multiple_status' );
			$product_listing_page_enable = get_option( 'acss_product_listing_page' );
			$product_listing_location    = get_option( 'acss_select_location' );
			$detail_page_enable          = get_option( 'acss_product_detail_page' );
			if ( empty( $default_enable_pro_page ) ) {
				update_option( 'acss_default_stock_enable_pro_page', 'yes' );
			}
			if ( empty( $default_enable ) ) {
				update_option( 'acss_default_stock_enable', '' );
			}
			if ( empty( $multiple_enable ) ) {
				update_option( 'acss_show_multiple_status', '' );
			}
			if ( empty( $product_listing_page_enable ) ) {
				update_option( 'acss_product_listing_page', 'yes' );
			}
			if ( empty( $product_listing_location ) ) {
				update_option( 'acss_select_location', 'Title' );
			}
			if ( empty( $detail_page_enable ) ) {
				update_option( 'acss_product_detail_page', 'yes' );
			}
		}

		public function delete_custom_stock_status() {
			$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field( $_POST['nonce'] ) : 0 ; 
			if (!wp_verify_nonce($nonce , 'acss-ajax-nonce') ) {
				die('Security Failed in main file 98');
			}
			if (isset($_POST['rule_id'])) {
				$rule_ID = intval($_POST['rule_id']);
			}
			wp_delete_post($rule_ID);
			die();
		}

		public function acss_custom_stock_status() {
			$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field( $_POST['nonce'] ) : 0 ;
			if (!wp_verify_nonce($nonce , 'acss-ajax-nonce')) {
				die('Security Failed in main file 110');
			}
			if (isset($_POST['post_id'])) {
				$Post_ID = intval($_POST['post_id']);
			}
			$acss_new_sub_rule   = array(
				'post_title'    => '',
				'post_content'  => '',
				'post_status'   => 'draft',
				'post_author'   => 1,
				'post_type'     => 'acss_sub_rules', 
				'post_parent' => $Post_ID,
			);
			$sub_rule_id         = wp_insert_post($acss_new_sub_rule);
			$acss_sub_rule_title = '';
			$acss_sub_rule_menu  = '';
			$acss_stock_min      = '';
			$acss_stock_max      = '';
			$message_type        = '';
			$acss_message        = '';
			$acss_icon_message   = '' ;
			$acss_icon           = '';
			$acss_image          = '';
			$acss_date_message   = '';
			$acss_date           = '';
			$acss_out_of_stock   = '';
			$acss_back_orders    = '';

			ob_start();
			include  ACSS_PLUGIN_DIR . 'includes/meta-boxes/new-rule-html.php';
			$acss_data = ob_get_clean();

			wp_send_json(
				array(
					'sub-rule-id'  => $sub_rule_id,
					'acss-data' => $acss_data,
				)
			);

			die();
		}

		public function a_c_s_s_global_constants_vars() {

			if ( ! defined( 'ACSS_URL' ) ) {
				define( 'ACSS_URL', plugin_dir_url( __FILE__ ) );
			}

			if ( ! defined( 'ACSS_BASENAME' ) ) {
				define( 'ACSS_BASENAME', plugin_basename( __FILE__ ) );
			}

			if ( ! defined( 'ACSS_PLUGIN_DIR' ) ) {
				define( 'ACSS_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
			}
		}

		public function acss_register_post_type() {

			$labels1 = array(
				'name'                => esc_html__( 'Custom Stock Status', 'addify_css' ),
				'singular_name'       => esc_html__( 'Custom Stock Status', 'addify_css' ),
				'add_new'             => esc_html__( 'Add New', 'addify_css' ),
				'add_new_item'        => esc_html__( 'Rule Title', 'addify_css' ),
				'edit_item'           => esc_html__( 'Edit Rule', 'addify_css' ),
				'new_item'            => esc_html__( 'New Template', 'addify_css' ),
				'view_item'           => esc_html__( 'View Template', 'addify_css' ),
				'search_items'        => esc_html__( 'Search Rules', 'addify_css' ),
				'exclude_from_search' => true,
				'not_found'           => esc_html__( 'No Rule found', 'addify_css' ),
				'not_found_in_trash'  => esc_html__( 'No Rule found in trash', 'addify_css' ),
				'parent_item_colon'   => '',
				'menu_name'           => esc_html__( 'Custom Stock', 'addify_css' ),
				'attributes'		  => esc_html__( 'Rule Priority', 'addify_css' ),
			);

			$args1 = array(
				'labels'             => $labels1,
				'menu_icon'          => plugins_url( 'assets/img/grey.png', __FILE__ ),
				'public'             => false,
				'publicly_queryable' => false,
				'show_ui'            => true,
				'show_in_menu'       => 'woocommerce',
				'query_var'          => true,
				'rewrite'            => true,
				'capability_type'    => 'post',
				'has_archive'        => true,
				'hierarchical'       => false,
				'menu_position'      => 30,
				'rewrite'            => array('slug' => 'acss_rules' ),
				'supports'           => array( 'title','page-attributes'),
			);

			register_post_type( 'acss_rules', $args1 );


			$sub_rules = array(
				'name'                => esc_html__( 'Stock Sub Rule', 'addify_css' ),
				'singular_name'       => esc_html__( 'Stock Sub Rule', 'addify_css' ),
				'add_new'             => esc_html__( 'New Sub Rule', 'addify_css' ),
				'add_new_item'        => esc_html__( 'Sub Rule Title', 'addify_css' ),
				'edit_item'           => esc_html__( 'Edit Sub Rule', 'addify_css' ),
				'search_items'        => esc_html__( 'Search Sub Rules', 'addify_css' ),
				'exclude_from_search' => true,
				'not_found'           => esc_html__( 'No Sub Rule found', 'addify_css' ),
				'not_found_in_trash'  => esc_html__( 'No Sub Rule found in trash', 'addify_css' ),
				'parent_item_colon'   => '',
				'menu_name'           => esc_html__( 'Stock Sub Rules', 'addify_css' ),
			);

			$sub_rule_args = array(
				'labels'             => $sub_rules,
				'menu_icon'          => plugins_url( 'assets/img/grey.png', __FILE__ ),
				'public'             => false,
				'publicly_queryable' => false,
				'show_ui'            => true,
				'show_in_menu'       => false,
				'query_var'          => true,
				'rewrite'            => true,
				'capability_type'    => 'post',
				'has_archive'        => true,
				'hierarchical'       => false,
				'menu_position'      => 30,
				'rewrite'            => array('slug' => 'acss_sub_rules' ),
				'supports'           => array( 'title'),
			);

			register_post_type( 'acss_sub_rules', $sub_rule_args );
		}

		public function a_c_s_s_load_text_domain() {
			if ( function_exists( 'load_plugin_textdomain' ) ) {
				load_plugin_textdomain( 'addify_css', false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
			}
		}

	}
	new Custom_Stock_Status();
}
