<?php

defined('ABSPATH') || exit;

class WC_Settings_Addify_Custom_Stock_Status extends WC_Settings_Page {

	/**
	 * Constructor
	 */
	public function __construct() {

		$this->id = 'afdcss';

		add_filter( 'woocommerce_settings_tabs_array', array( $this, 'add_settings_tab' ), 50 );
		add_action( 'woocommerce_sections_' . $this->id, array( $this, 'output_sections' ) );
		add_action( 'woocommerce_settings_' . $this->id, array( $this, 'output' ) );
		add_action( 'woocommerce_settings_save_' . $this->id, array( $this, 'save' ) );
	}

	/**
	 * Add plugin options tab
	 *
	 * @return array
	 */
	public function add_settings_tab( $settings_tabs ) {
		$settings_tabs[$this->id] = __( 'Custom Stock Status', 'addify_css' );
		return $settings_tabs;
	}

	/**
	 * Get sections
	 *
	 * @return array
	 */
	public function get_sections() {

		$sections = array(
			''                 => __( 'General Setting', 'addify_css' ),
			'c-s-s-styling-cstmsg' => __( 'Custom Message Styling', 'addify_css' ),
			'c-s-s-display-setting'  => __( 'Shortcode', 'addify_css' ),
		);

		return apply_filters( 'woocommerce_get_sections_' . $this->id, $sections );
	}


	/**
	 * Get sections
	 *
	 * @return array
	 */
	public function get_settings( $section = null, $settings = null ) {

		if (!current_user_can('manage_options')) {
			return;
		}
		$settings = array();

		if (null == $section) {

			// Add Title to the Settings
			$settings[] = array( 'name' => __( 'General Setting', 'addify_css' ), 'type' => 'title', 'id' => 'c-s-s-general-setting-option' );

			$settings[] = array(
				'name'     => __( 'Display custom stock status (Shop Page).', 'addify_css' ),
				'id'       => 'acss_product_listing_page',
				'type'     => 'checkbox',
				'desc_tip'     => __( 'Display custom stock status on shop page.', 'addify_css' ),
			);

			$settings[] = array(
				'name'     => __( 'Set Location where to show custom status (Shop Page).', 'addify_css' ),
				'id'       => 'acss_select_location',
				'type' => 'select',
				'desc_tip'     => __( 'Choose Location where you want to show custom stock status on shop page.', 'addify_css' ),
				'options' => array(

					  'select' => __( 'Select Location' ),
					  'BeforeTitle' => __('Before Product Title'),
					  'Title' => __( 'After Product Title' ),
					  'Price' => __( 'After Product Price' ),
					  'Cart' => __( 'After Add to cart button' )

				)
			);
			$settings[] = array(
				'name'     => __( 'Display default stock status (Shop Page).', 'addify_css' ),
				'id'       => 'acss_default_stock_enable',
				'type'     => 'checkbox',
				'desc_tip'     => __( 'Allows admin to show default stock status with custom status on shop page.', 'addify_css' ),
			);

			$settings[] = array(
				'name'     => __( 'Display custom stock status (Product Detail page).', 'addify_css' ),
				'id'       => 'acss_product_detail_page',
				'type'     => 'checkbox',
				'desc_tip'     => __( 'Display custom stock status on product detail page.', 'addify_css' ),
			);

			$settings[] = array(
				'name'     => __( 'Display default stock status (Product Detail page).', 'addify_css' ),
				'id'       => 'acss_default_stock_enable_pro_page',
				'type'     => 'checkbox',
				'desc_tip'     => __( 'Allows admin to show default stock status with custom status on product page.', 'addify_css' ),
			);

			$settings[] = array(
				'name'     => __( 'Show Multiple Status', 'addify_css' ),
				'id'       => 'acss_show_multiple_status',
				'type'     => 'checkbox',
				'desc_tip'     => __( 'Enable if want to implement multiple rules on product detail page & shop page.', 'addify_css' ),
			);


			$settings[] = array( 'type' => 'sectionend', 'id' => 'c-s-s-general-setting-option' );

			
		} elseif ('c-s-s-styling-cstmsg' == $section) {

			$settings[] = array( 'name' => __( 'Custom Message Styling', 'addify_css' ), 'type' => 'title', 'id' => 'c-s-s-cstmsg-style-tab-section' );

			$settings[] = array(
				'name'     => __( 'Stock message color.', 'addify_css' ),
				'id'       => 'acss_message_color',
				'type'     => 'color',
				'desc_tip'     => __( 'Select stock message color.', 'addify_css' ),
			);


			$settings[] = array(
				'name'     => __( 'Stock message Font.', 'addify_css' ),
				'id'       => 'acss_message_font',
				'type'     => 'number',
				'desc_tip'     => __( 'Set stock message font.', 'addify_css' ),
			);

			$settings[] = array( 'type' => 'sectionend', 'id' => 'c-s-s-cstmsg-style-tab-section' );
		} elseif ('c-s-s-display-setting' == $section) {
			$settings[] = array( 'name' => __( 'Shortcode', 'addify_css' ), 'type' => 'title', 'id' => 'c-s-s-short-code-tab-section' );

			$settings[] = array(
				'name'     	=> __( 'Shortcode', 'addify_css' ),
				'id'       	=> 'acss_short_code',
				'type'     	=> 'text',
				'value' 	=> '   ',
			);

			$settings[] = array( 'type' => 'sectionend', 'id' => 'c-s-s-short-code-tab-section' );

		}
		return apply_filters( 'wc_settings_tab_c_s_s_settings', $settings, $section );
	}
	public function output() {
		global $current_section;

		$settings = $this->get_settings( $current_section );
		if (!empty($settings )) {
			WC_Admin_Settings::output_fields( $settings );
		}
	}


	/**
	 * Save settings
	 */
	public function save() {
		global $current_section;
		$settings = $this->get_settings( $current_section );
		WC_Admin_Settings::save_fields( $settings );
	}

}
return new WC_Settings_Addify_Custom_Stock_Status();
