<?php
/**
 * Admin file of Module
 *
 * Manage all settings and actions of admin
 *
 * @package  addify-custom-stock-status/includes
 * @version  1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; 
}

if ( ! class_exists( 'Admin_Addify_CSS' ) ) {

	class Admin_Addify_CSS extends Custom_Stock_Status {

		public function __construct() {
			add_action( 'admin_enqueue_scripts', array( $this, 'acss_admin_assests' ), 10 );
			// add_action( 'admin_menu', array( $this, 'acss_admin_menu' ) );
			// add_action( 'admin_init', array( $this, 'acss_add_setting_files' ), 10 );
			add_action( 'add_meta_boxes', array( $this, 'acss_add_metaboxes' ) );
			add_action( 'save_post', array( $this, 'addify_acss_save_metadata' ), 10, 2 );
			add_action( 'wp_ajax_acsssearchProducts', array( $this, 'acsssearchProducts' ) ); 
			add_filter( 'woocommerce_get_settings_pages', array($this, 'c_s_s_add_settings_page' ), 50);
			
		}

		public function c_s_s_add_settings_page( $settings) {

			$settings[] = include_once ACSS_PLUGIN_DIR . '/includes/Settings/class-af-c-s-s-general-setting.php' ;  
				return $settings;
		}  

		public function acss_add_metaboxes() {
			add_meta_box(
				'rule-priority',
				__( 'Rule Attributes', 'addify-css' ),
				array( $this, 'acss_rule_priority_metabox_callback' ),
				'acss_rules'
			);
			add_meta_box(
				'sub-rules',
				__( 'Sub Rules For Messages', 'addify-css' ),
				array( $this, 'acss_sub_rules_metabox_callback' ),
				'acss_rules'
			);
		}

		public function acss_rule_priority_metabox_callback() {
			include_once ACSS_PLUGIN_DIR . 'includes/meta-boxes/rulepriority-settings.php';
			include_once ACSS_PLUGIN_DIR . 'includes/meta-boxes/productrules-settings.php';
		}

		public function acss_sub_rules_metabox_callback() {
			include_once ACSS_PLUGIN_DIR . 'includes/meta-boxes/subrules-settings.php';
		}

		public function addify_acss_save_metadata( $post_id, $post = false ) {
			// Return if not relevant post type.
			if ( 'acss_rules' !== $post->post_type ) {
				return;
			}

			// Return if we're doing an auto save.
			if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
				return;
			}

			if ( 'auto-draft' === get_post_status( $post_id ) ) {
				return;
			}

			include_once ACSS_PLUGIN_DIR . 'includes/meta-boxes/save-metaboxes.php';
		}

		public function acss_admin_assests() {

			wp_enqueue_style( 'acss-admin', ACSS_URL . 'assets/css/addify-admin-css.css', false, '1.0' );
			wp_enqueue_style( 'select2', ACSS_URL . 'assets/css/select2.css', false, '1.0' );

			wp_enqueue_script( 'jquery' );

			wp_enqueue_script( 'select2', ACSS_URL . 'assets/js/select2.js', array( 'jquery' ) , '1.0', false );

			wp_enqueue_script( 'acss-admin-js', ACSS_URL . 'assets/js/addify-admin-css.js', array( 'jquery' ), '1.0', false );
			wp_enqueue_media();
			ob_start();
			include  ACSS_PLUGIN_DIR . 'template/c-s-s-template-file.php';
			$result    = ob_get_clean();
			$acss_data = array(
						'admin_url' => admin_url( 'admin-ajax.php' ),
						'nonce'     => wp_create_nonce( 'acss-ajax-nonce' ),
						'c_s_s_html' => $result,
						);
			wp_localize_script( 'acss-admin-js', 'acss_php_vars', $acss_data );
				 
		}

		public function acsssearchProducts() {

			$nonce = isset( $_POST['nonce'] ) ? sanitize_text_field( $_POST['nonce'] ) : 0;
			if (!wp_verify_nonce($nonce, 'acss-ajax-nonce')) {
				 die('Admin Side Security Failed');
			} 
			
			if ( isset( $_POST['q'] ) && '' != $_POST['q'] ) {

				$pro = sanitize_text_field( $_POST['q'] );

			} else {

				$pro = '';

			}

			$data_array = array();
			$args       = array(
				'post_type'   => array('product','product_variation'),
				'post_status' => 'publish',
				'numberposts' => -1,
				's'           => $pro,
			);
			$pros       = get_posts( $args );

			if ( ! empty( $pros ) ) {

				foreach ( $pros as $proo ) {

					$title        = ( mb_strlen( $proo->post_title ) > 50 ) ? mb_substr( $proo->post_title, 0, 49 ) . '...' : $proo->post_title;
					$data_array[] = array( $proo->ID, $title ); 
				}
			}
			echo wp_json_encode( $data_array );
			die();
		}

	}
	new Admin_Addify_CSS();
}
