<?php
/**
 * Front file of Module
 *
 * Manage actions of front
 *
 * @package  addify-custom-stock-status/includes
 * @version  1.0.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

if ( ! class_exists( 'Class_Front_Addify_Css' ) ) {
	/**
	 * Front class of module.
	 */
	class Class_Front_Addify_Css extends Custom_Stock_Status {

		public function __construct() {
			$this->acss_rules = $this->acss_get_stock_rules();
			add_action( 'wp_enqueue_scripts', array( $this, 'acss_front_assets' ), 10 );
			add_filter('woocommerce_single_product_summary', array( $this, 'acss_product_page_hook_callback' ), 30 );
			add_filter( 'woocommerce_available_variation', array($this, 'acss_all_available_variable_product_hook'), 10, 3 );
			add_action( 'init' , array( $this, 'custom_stock_status_shop_callback'), 10);
			add_filter( 'woocommerce_get_stock_html', array($this , 'filter_woocommerce_get_stock_html' ), 10, 2 ); 
			add_shortcode('addify_custom_stock_status', array($this, 'acssm_rule_shortcode_call_back') );
		}

		public function acss_front_assets() {
			wp_enqueue_style( 'acss-front', ACSS_URL . 'assets/css/addify-front-css.css', false, '1.0' );

			wp_enqueue_script( 'acss-front-js', ACSS_URL . 'assets/js/addify-front-css.js', array( 'jquery' ), '1.0', false );
		}

		public function filter_woocommerce_get_stock_html( $html, $product) {
			$show_default_status_pro_page = get_option( 'acss_default_stock_enable_pro_page' );
			if (is_product()) {
				if ('yes' === $show_default_status_pro_page) {
					return $html; 
				} else {
					$html = '' ;
					return $html;
				}
			}
					return $html;
		}

		public function acssm_rule_shortcode_call_back() {
			 include_once ACSS_PLUGIN_DIR . '/includes/short-code-af-c-s-s-file.php';
		}

		public function acss_all_available_variable_product_hook( $data, $product, $variation) {

			$show_on_product_page = get_option ('acss_product_detail_page');
			$show_multiple_status = get_option( 'acss_show_multiple_status' );
			$stock_color          = get_option('acss_message_color');
			$stock_font           = get_option ( 'acss_message_font');
			$acss_qty             = $product->get_stock_quantity();

			if ( 'yes' !== get_post_meta($variation->get_id(), '_manage_stock', true ) ) {
				return $data;
			}

			if ('yes' !== $show_on_product_page ) {
				return $data;
			}

			ob_start();
			?>
			<div class="main_status_div_product_page">
			
			<?php

			foreach ($this->acss_rules as $rules) {
				if ( !$this->acss_check_rules_for_product( $variation->get_id(), $rules->ID ) ) {
					continue;
				}

				$Sub_rules     = $this->acss_get_sub_rules($rules->ID);
					$stock_qty = $variation->get_stock_quantity();
				if (!empty($Sub_rules)) {
					foreach ( $Sub_rules as $sub_rule) {
						$sub_rule_id              = $sub_rule->ID;
						$acss_sub_rule_title      = $sub_rule->post_title;
						$acss_sub_rule_menu       = $sub_rule->menu_order;
						$acss_enable_out_of_stock = get_post_meta( $sub_rule_id, 'acss_enableout_of_stock' , true);
						$acss_stock_min           = get_post_meta( $sub_rule_id, 'acss_min_stock', true );
						$acss_stock_max           = get_post_meta( $sub_rule_id, 'acss_max_stock', true );
						$acss_back_orders         = get_post_meta( $sub_rule_id, 'acss_back_orders', true);
						$acss_instock_color       = get_post_meta( $sub_rule_id, 'acss_instock_color', true );
						$acss_outstock_color      = get_post_meta( $sub_rule_id, 'acss_outstock_color', true );
						$acss_backorder_color     = get_post_meta( $sub_rule_id, 'acss_backorder_color', true);
						$acss_instock_font        = get_post_meta( $sub_rule_id, 'acss_instock_font' , true);
						$acss_outstock_font       = get_post_meta( $sub_rule_id, 'acss_outstock_font' , true);
						$acss_backorder_font      = get_post_meta( $sub_rule_id, 'acss_backorder_font' , true);
						$stock_color              = get_option('acss_message_color');
						$stock_font               = get_option ( 'acss_message_font');

						if (!empty($acss_instock_color)) {
								$acss_instock_color = $acss_instock_color;
						} elseif (!empty($stock_color)) {
								$acss_instock_color = $stock_color;
						}

						if (!empty($acss_instock_font)) {
								$acss_instock_font = $acss_instock_font;
						} elseif (!empty($stock_color)) {
								$acss_instock_font = $stock_font;
						}

						if (!empty($acss_outstock_color)) {
								$acss_outstock_color = $acss_outstock_color;
						} elseif (!empty($stock_color)) {
								$acss_outstock_color = $stock_color;
						}

						if (!empty($acss_outstock_font)) {
								$acss_outstock_font = $acss_outstock_font;
						} elseif (!empty($stock_color)) {
								$acss_outstock_font = $stock_font;
						}

						if (!empty($acss_backorder_color)) {
								$acss_backorder_color = $acss_backorder_color;
						} elseif (!empty($stock_color)) {
								$acss_backorder_color = $stock_color;
						}
						
						if (!empty($acss_backorder_font)) {
								$acss_backorder_font = $acss_backorder_font;
						} elseif (!empty($stock_color)) {
								$acss_backorder_font = $stock_font;
						}

						$acss_enable_backorders = get_post_meta( $variation->get_id(), '_backorders' , true);
						$stock_quantity_woo     = get_post_meta( $variation->get_id(), '_stock', true );

						if ('yes' !== $acss_enable_out_of_stock && 'yes'!== $acss_back_orders) {
							if (!$this->acss_check_stock_for_product($stock_qty, $acss_stock_min , $acss_stock_max  )) {
								continue;
							}
						}
							
							
						$message_type      = get_post_meta( $sub_rule_id, 'acss_select_message', true);
						$acss_message      = get_post_meta( $sub_rule_id, 'acss_text_message', true );
						$acss_icon_message = get_post_meta( $sub_rule_id, 'acss_icon_message', true ) ;
						$acss_icon         = get_post_meta( $sub_rule_id, 'acss_icon', true );
						$acss_image        = get_post_meta( $sub_rule_id, 'acss_image', true);
						$acss_date_message = get_post_meta( $sub_rule_id, 'acss_date_message', true);
						$acss_date         = get_post_meta( $sub_rule_id, 'acss_date' , true);

						$acss_message      = str_replace('{stock_qty}', $stock_qty, $acss_message);
						$acss_icon_message = str_replace('{stock_qty}', $stock_qty, $acss_icon_message);
						$acss_date_message = str_replace('{stock_qty}', $stock_qty, $acss_date_message);


						if ( 0 >= $stock_quantity_woo && ( 'notify' === $acss_enable_backorders || 'yes' ===$acss_enable_backorders )) {
							if ('yes' !== $acss_back_orders) {
								continue;
							}
						} elseif (!$variation->is_in_stock()) {
							if ('yes' !== $acss_enable_out_of_stock ) {
								continue;
							}
						} else {
							if ('yes' === $acss_enable_out_of_stock || 'yes' === $acss_back_orders ) {
								continue;
							}
						}

						?>
					<div class="acss_sub_rule_div_product_page"> 
						<?php 
						if ('text' === $message_type) {
							if ('yes' === $acss_enable_out_of_stock) {
								?>
								<div class="acss_text_div">
								<p class="acss_text" style="color:<?php echo esc_html( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;"><?php echo esc_html( $acss_message); ?></p>
								</div> 
								<?php
							} elseif ('yes' === $acss_back_orders) {
								?>
								<div class="acss_text_div">
								<p class="acss_text" style="color:<?php echo esc_html( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;"><?php echo esc_html( $acss_message); ?></p>
								</div> 
								<?php
							} else {
								?>
								<div class="acss_text_div">
								<p class="acss_text" style="color:<?php echo esc_html( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;"><?php echo esc_html( $acss_message); ?></p>
								</div> 
								<?php
							}
							
								 
						}
						if ('icon' === $message_type) {
							if ('yes' === $acss_enable_out_of_stock) {
								?>
								<div class="acss_icon_div">
									<?php 
									if ($acss_icon) { 
										?>
										<div class="css_icon">
											<img class="img_class" src= "<?php echo esc_html( $acss_icon ); ?>" />
										</div>
											<?php } ?>
										<div class="icon_message_class">
											<p style="color:<?php echo esc_html( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;">
												<?php echo esc_html( $acss_icon_message ); ?>
										</p>
										</div>
									</div>
								<div style='clear:both'></div>
								<?php 
							} elseif ('yes' === $acss_back_orders) {
								?>
								<div class="acss_icon_div">
									<?php 
									if ($acss_icon) { 
										?>
										<div class="css_icon">
											<img class="img_class" src= "<?php echo esc_html( $acss_icon ); ?>" />
										</div>
											<?php } ?>
										<div class="icon_message_class">
											<p style="color:<?php echo esc_html( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;">
												<?php echo esc_html( $acss_icon_message ); ?>
										</p>
										</div>
									</div>
								<div style='clear:both'></div>
								<?php
							} else {
								?>
								<div class="acss_icon_div">
									<?php 
									if ($acss_icon) { 
										?>
										<div class="css_icon">
											<img class="img_class" src= "<?php echo esc_html( $acss_icon ); ?>" />
										</div>
											<?php } ?>
										<div class="icon_message_class">
											<p style="color:<?php echo esc_html( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;">
												<?php echo esc_html( $acss_icon_message ); ?>
										</p>
										</div>
									</div>
								<div style='clear:both'></div>
								<?php
							}
						}
							
						if ('image' === $message_type) {
							if ($acss_image) {
								?>
									<div class="acss_image_div">
									<img class="acss_image" src="<?php echo esc_html( $acss_image ); ?> "/>
									</div>
									<?php
							} 
						}
						if ('date' === $message_type) {
							if ('yes' === $acss_enable_out_of_stock) {
								?>
								<div class="acss_date_div">
								<p class="acss_date" style="color:<?php echo esc_html ( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
								</div>	
								<?php 
							} elseif ('yes' === $acss_back_orders) {
								?>
								<div class="acss_date_div">
								<p class="acss_date" style="color:<?php echo esc_html ( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
								</div>	
								<?php   
							} else {
								?>
								<div class="acss_date_div">
								<p class="acss_date" style="color:<?php echo esc_html ( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
								</div>	
								<?php
							} 
						} 
						?>
						</div>	
						<?php 
					}
				}
				if ('yes' !== $show_multiple_status) {
					break;
				}
			}
				
			?>
		</div>
			<?php
			$data['price_html'] .= ob_get_clean();
			return $data;
				
		}


		public function acss_product_page_hook_callback () {
			global $product;
				$show_default_status_pro_page = get_option( 'acss_default_stock_enable_pro_page' );
				$show_on_product_page         = get_option ('acss_product_detail_page');
				$show_multiple_status         = get_option( 'acss_show_multiple_status' );
				$stock_color                  = get_option('acss_message_color');
				$stock_font                   = get_option ( 'acss_message_font');
				$acss_qty                     = $product->get_stock_quantity();

			if ( 'yes' !== get_post_meta($product->get_id(), '_manage_stock', true ) ) {
				return;
			}
			if ('yes'=== $show_default_status_pro_page && 'variable' === $product->get_type()) {
				echo wp_kses_post(wc_get_stock_html($product));
			}
			
			if ('yes' === $show_on_product_page ) {
				
				?>
			<div class="main_status_div_product_page">
				<?php
				foreach ($this->acss_rules as $rules) {
					if ( !$this->acss_check_rules_for_product( $product->get_id(), $rules->ID ) ) {
						continue;
					}
					$Sub_rules = $this->acss_get_sub_rules($rules->ID);
					$stock_qty = $product->get_stock_quantity();
					if (!empty($Sub_rules)) {
						foreach ( $Sub_rules as $sub_rule) {
							$sub_rule_id              = $sub_rule->ID;
							$acss_sub_rule_title      = $sub_rule->post_title;
							$acss_sub_rule_menu       = $sub_rule->menu_order;
							$acss_enable_out_of_stock = get_post_meta( $sub_rule_id, 'acss_enableout_of_stock' , true);
							$acss_stock_min           = get_post_meta( $sub_rule_id, 'acss_min_stock', true );
							$acss_stock_max           = get_post_meta( $sub_rule_id, 'acss_max_stock', true );
							$acss_back_orders         = get_post_meta( $sub_rule_id, 'acss_back_orders', true);
							$acss_enable_backorders   = get_post_meta( $product->get_id(), '_backorders' , true);
							$stock_quantity_woo       = get_post_meta( $product->get_id(), '_stock', true );

							$acss_instock_color   = get_post_meta( $sub_rule_id, 'acss_instock_color', true );
							$acss_outstock_color  = get_post_meta( $sub_rule_id, 'acss_outstock_color', true );
							$acss_backorder_color = get_post_meta( $sub_rule_id, 'acss_backorder_color', true);

							$acss_instock_font   = get_post_meta( $sub_rule_id, 'acss_instock_font' , true);
							$acss_outstock_font  = get_post_meta( $sub_rule_id, 'acss_outstock_font' , true);
							$acss_backorder_font = get_post_meta( $sub_rule_id, 'acss_backorder_font' , true);
							if (!empty($acss_instock_color)) {
								$acss_instock_color = $acss_instock_color;
							} elseif (!empty($stock_color)) {
								$acss_instock_color = $stock_color;
							}

							if (!empty($acss_instock_font)) {
								$acss_instock_font = $acss_instock_font;
							} elseif (!empty($stock_color)) {
								$acss_instock_font = $stock_font;
							}

							if (!empty($acss_outstock_color)) {
								$acss_outstock_color = $acss_outstock_color;
							} elseif (!empty($stock_color)) {
								$acss_outstock_color = $stock_color;
							}

							if (!empty($acss_outstock_font)) {
								$acss_outstock_font = $acss_outstock_font;
							} elseif (!empty($stock_color)) {
								$acss_outstock_font = $stock_font;
							}

							if (!empty($acss_backorder_color)) {
								$acss_backorder_color = $acss_backorder_color;
							} elseif (!empty($stock_color)) {
								$acss_backorder_color = $stock_color;
							}
						
							if (!empty($acss_backorder_font)) {
								$acss_backorder_font = $acss_backorder_font;
							} elseif (!empty($stock_color)) {
								$acss_backorder_font = $stock_font;
							}
							if ('yes' !== $acss_enable_out_of_stock && 'yes'!== $acss_back_orders) {
								if (!$this->acss_check_stock_for_product($stock_qty, $acss_stock_min , $acss_stock_max  )) {
									continue;
								}
							}
							

							$message_type      = get_post_meta( $sub_rule_id, 'acss_select_message', true);
							$acss_message      = get_post_meta( $sub_rule_id, 'acss_text_message', true );
							$acss_icon_message = get_post_meta( $sub_rule_id, 'acss_icon_message', true ) ;
							$acss_icon         = get_post_meta( $sub_rule_id, 'acss_icon', true );
							$acss_image        = get_post_meta( $sub_rule_id, 'acss_image', true);
							$acss_date_message = get_post_meta( $sub_rule_id, 'acss_date_message', true);
							$acss_date         = get_post_meta( $sub_rule_id, 'acss_date' , true);

							$acss_message      = str_replace('{stock_qty}', $stock_qty, $acss_message);
							$acss_icon_message = str_replace('{stock_qty}', $stock_qty, $acss_icon_message);
							$acss_date_message = str_replace('{stock_qty}', $stock_qty, $acss_date_message);
							
							if ( 0 >= $stock_quantity_woo && ( 'notify' === $acss_enable_backorders || 'yes' ===$acss_enable_backorders )) {
								if ('yes' !== $acss_back_orders) {
									continue;
								}
							} elseif (!$product->is_in_stock()) {
								if ('yes' !== $acss_enable_out_of_stock ) {
									continue;
								}
							} else {
								if ('yes' === $acss_enable_out_of_stock || 'yes' === $acss_back_orders ) {
									continue;
								}
							}


							?>
					<div class="acss_sub_rule_div_product_page"> 
							<?php 
							if ('text' === $message_type) {

								if ('yes' === $acss_enable_out_of_stock ) {
									?>
									<div class="acss_text_div">
									<p class="acss_text" style="color:<?php echo esc_html( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;"><?php echo esc_html( $acss_message); ?></p>
									</div>
									<?php
								} elseif ('yes' === $acss_back_orders) {
									?>
									<div class="acss_text_div">
									<p class="acss_text" style="color:<?php echo esc_html( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;"><?php echo esc_html( $acss_message); ?></p>
									</div>
									<?php
								} else {
									?>
									<div class="acss_text_div">
									<p class="acss_text" style="color:<?php echo esc_html( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;"><?php echo esc_html( $acss_message); ?></p>
									</div>
									<?php
								} 
							}
							if ('icon' === $message_type) {

								if ('yes' === $acss_enable_out_of_stock ) {

									?>
									<div class="acss_icon_div">
											<?php 
											if ($acss_icon) { 
												?>
										<div class="css_icon">
											<img class="img_class" src= "<?php echo esc_html( $acss_icon ); ?>" />
										</div>
											<?php } ?>
										<div class="icon_message_class">
											<p style="color:<?php echo esc_html( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;">
													<?php echo esc_html( $acss_icon_message ); ?>
										</p>
										</div>
									</div>
									<div style='clear:both'></div>
									<?php
								 
								} elseif ('yes' === $acss_back_orders) {

									?>
									<div class="acss_icon_div">
											<?php 
											if ($acss_icon) { 
												?>
										<div class="css_icon">
											<img class="img_class" src= "<?php echo esc_html( $acss_icon ); ?>" />
										</div>
											<?php } ?>
										<div class="icon_message_class">
											<p style="color:<?php echo esc_html( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;">
													<?php echo esc_html( $acss_icon_message ); ?>
										</p>
										</div>
									</div>
									<div style='clear:both'></div>
									<?php
									 
								} else {

									?>
									<div class="acss_icon_div">
											<?php 
											if ($acss_icon) { 
												?>
										<div class="css_icon">
											<img class="img_class" src= "<?php echo esc_html( $acss_icon ); ?>" />
										</div>
											<?php } ?>
										<div class="icon_message_class">
											<p style="color:<?php echo esc_html( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;">
													<?php echo esc_html( $acss_icon_message ); ?>
										</p>
										</div>
									</div>
									<div style='clear:both'></div>
									<?php
									
								}	 
							}
							if ('image' === $message_type) {
								if ($acss_image) {
									?>
									<div class="acss_image_div">
									<img class="acss_image" src="<?php echo esc_html( $acss_image ); ?> "/>
									</div>
										<?php
								} 
							}
							if ('date' === $message_type) {

								if ('yes' === $acss_enable_out_of_stock ) {
									?>
									<div class="acss_date_div">
									<p class="acss_date" style="color:<?php echo esc_html ( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
									</div>	
									<?php 
								 
								} elseif ('yes' === $acss_back_orders) {
									?>
									<div class="acss_date_div">
									<p class="acss_date" style="color:<?php echo esc_html ( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
									</div>	
									<?php 
								} else {
									?>
									<div class="acss_date_div">
									<p class="acss_date" style="color:<?php echo esc_html ( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
									</div>	
									<?php 
								}

							} 
							?>
							</div>	
							<?php 
						}
					}
					if ('yes' !== $show_multiple_status) {
						break;
					}
				}
				
				?>
		</div> 
				<?php
			}
		}



		public function custom_stock_status_shop_callback() {
			$acss_product_listing_page = get_option('acss_product_listing_page');
			$acss_select_location      = get_option('acss_select_location');
			if ('yes' === $acss_product_listing_page) {
				if ('BeforeTitle' === $acss_select_location ) {

					add_action( 'woocommerce_before_shop_loop_item_title', array( $this , 'shop_page_acss_callback') , 10);

				} elseif ('Price' === $acss_select_location ) {
					add_action( 'woocommerce_after_shop_loop_item_title' , array( $this , 'shop_page_acss_callback'), 10);

				} elseif ('Cart' === $acss_select_location ) {
					add_action( 'woocommerce_after_shop_loop_item' , array($this ,'shop_page_acss_callback' ), 10);

				} else {
					add_action( 'woocommerce_shop_loop_item_title' , array($this ,'shop_page_acss_callback'), 10);
				}

			}
		}

		public function shop_page_acss_callback() {

			global $product;

				$show_default_status  = get_option( 'acss_default_stock_enable' );
				$show_multiple_status = get_option( 'acss_show_multiple_status' );
				$stock_color          = get_option('acss_message_color');
				$stock_font           = get_option ( 'acss_message_font'); 
			
				$acss_qty = $product->get_stock_quantity();

			if ( 'yes' !== get_post_meta($product->get_id(), '_manage_stock', true ) ) {
				return;
			}

			if ('yes' === $show_default_status) {
				if ($product->is_purchasable()) {
					echo wp_kses_post(wc_get_stock_html($product));
				}
			}
			?>
		<div class="main_status_div">
				<ul>
					<?php
					foreach ($this->acss_rules as $rules) {

						if ( !$this->acss_check_rules_for_product( $product->get_id(), $rules->ID ) ) {
							continue;
						}

						$Sub_rules = $this->acss_get_sub_rules($rules->ID);
						
						$stock_qty = $product->get_stock_quantity();
						if (!empty($Sub_rules)) {
							foreach ( $Sub_rules as $sub_rule) {

								$sub_rule_id              = $sub_rule->ID;
								$acss_sub_rule_title      = $sub_rule->post_title;
								$acss_sub_rule_menu       = $sub_rule->menu_order;
								$acss_enable_out_of_stock = get_post_meta( $sub_rule_id, 'acss_enableout_of_stock' , true);
								$acss_stock_min           = get_post_meta( $sub_rule_id, 'acss_min_stock', true );
								$acss_stock_max           = get_post_meta( $sub_rule_id, 'acss_max_stock', true );
								$acss_back_orders         = get_post_meta( $sub_rule_id, 'acss_back_orders', true);
								$acss_enable_backorders   = get_post_meta ($product->get_id(), '_backorders' , true);
								$stock_quantity_woo       = get_post_meta( $product->get_id(), '_stock', true );
								$acss_instock_color       = get_post_meta( $sub_rule_id, 'acss_instock_color', true );
								$acss_outstock_color      = get_post_meta( $sub_rule_id, 'acss_outstock_color', true );
								$acss_backorder_color     = get_post_meta( $sub_rule_id, 'acss_backorder_color', true);

								$acss_instock_font   = get_post_meta( $sub_rule_id, 'acss_instock_font' , true);
								$acss_outstock_font  = get_post_meta( $sub_rule_id, 'acss_outstock_font' , true);
								$acss_backorder_font = get_post_meta( $sub_rule_id, 'acss_backorder_font' , true);

								if (!empty($acss_instock_color)) {
									$acss_instock_color = $acss_instock_color;
								} elseif (!empty($stock_color)) {
										$acss_instock_color = $stock_color;
								}

								if (!empty($acss_instock_font)) {
										$acss_instock_font = $acss_instock_font;
								} elseif (!empty($stock_color)) {
										$acss_instock_font = $stock_font;
								}

								if (!empty($acss_outstock_color)) {
										$acss_outstock_color = $acss_outstock_color;
								} elseif (!empty($stock_color)) {
										$acss_outstock_color = $stock_color;
								}

								if (!empty($acss_outstock_font)) {
										$acss_outstock_font = $acss_outstock_font;
								} elseif (!empty($stock_color)) {
										$acss_outstock_font = $stock_font;
								}

								if (!empty($acss_backorder_color)) {
										$acss_backorder_color = $acss_backorder_color;
								} elseif (!empty($stock_color)) {
										$acss_backorder_color = $stock_color;
								}
						
								if (!empty($acss_backorder_font)) {
										$acss_backorder_font = $acss_backorder_font;
								} elseif (!empty($stock_color)) {
										$acss_backorder_font = $stock_font;
								} 
								if ('yes' !== $acss_enable_out_of_stock && 'yes'!== $acss_back_orders) {
									if (!$this->acss_check_stock_for_product($stock_qty, $acss_stock_min , $acss_stock_max  )) {
										continue;
									}
								}

								$message_type      = get_post_meta( $sub_rule_id, 'acss_select_message', true);
								$acss_message      = get_post_meta( $sub_rule_id, 'acss_text_message', true );
								$acss_icon_message = get_post_meta( $sub_rule_id, 'acss_icon_message', true ) ;
								$acss_icon         = get_post_meta( $sub_rule_id, 'acss_icon', true );
								$acss_image        = get_post_meta( $sub_rule_id, 'acss_image', true);
								$acss_date_message = get_post_meta( $sub_rule_id, 'acss_date_message', true);
								$acss_date         = get_post_meta( $sub_rule_id, 'acss_date' , true);

								$acss_message      = str_replace('{stock_qty}', $stock_qty, $acss_message);
								$acss_icon_message = str_replace('{stock_qty}', $stock_qty, $acss_icon_message);
								$acss_date_message = str_replace('{stock_qty}', $stock_qty, $acss_date_message);



								if ( 0 >= $stock_quantity_woo && ( 'notify' === $acss_enable_backorders || 'yes' ===$acss_enable_backorders )) {
									if ('yes' !== $acss_back_orders) {
										continue;
									}
								} elseif (!$product->is_in_stock()) {
									if ('yes' !== $acss_enable_out_of_stock ) {
										continue;
									}
								} else {
									if ('yes' === $acss_enable_out_of_stock || 'yes' === $acss_back_orders ) {
										continue;
									}
								}

								?>
						<li class="acss_sub_rule_item"> 
								<?php 
								if ('text' === $message_type) {
									if ('yes' === $acss_enable_out_of_stock) {
										?>
										<div class="acss_text_div">
										<p class="acss_text" style="color:<?php echo esc_html( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;"><?php echo esc_html ($acss_message ); ?></p>
										</div>
										<?php 
									} elseif ('yes' === $acss_back_orders) {
										?>
										<div class="acss_text_div">
										<p class="acss_text" style="color:<?php echo esc_html( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;"><?php echo esc_html ($acss_message ); ?></p>
										</div>
										<?php
									} else {
										?>
										<div class="acss_text_div">
										<p class="acss_text" style="color:<?php echo esc_html( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;"><?php echo esc_html ($acss_message ); ?></p>
										</div>
										<?php
									}
									
								}

								if ('icon' === $message_type) {
									if ('yes' === $acss_enable_out_of_stock) {
										?>
										<div class="acss_text-with-icon">
											<div class="icon_message_class">
												<?php if ($acss_icon) { ?>
												<span class="img_class"><img src= "<?php echo esc_html( $acss_icon ); ?>" /></span>
												<?php } ?>
												<span style="color:<?php echo esc_html( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;">
														<?php echo esc_html( $acss_icon_message ); ?>
												</span>
											</div>
										</div>
										<div style='clear:both'></div>
										<?php 
									} elseif ('yes' === $acss_back_orders) {
										?>
										<div class="acss_text-with-icon">
											<div class="icon_message_class">
												<?php if ($acss_icon) { ?>
												<span class="img_class"><img src= "<?php echo esc_html( $acss_icon ); ?>" /></span>
												<?php } ?>
												<span style="color:<?php echo esc_html( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;">
														<?php echo esc_html( $acss_icon_message ); ?>
												</span>
											</div>
										</div>
										<div style='clear:both'></div>
										<?php
									} else {
										?>
										<div class="acss_text-with-icon">
											<div class="icon_message_class">
												<?php if ($acss_icon) { ?>
												<span class="img_class"><img src= "<?php echo esc_html( $acss_icon ); ?>" /></span>
												<?php } ?>
												<span style="color:<?php echo esc_html( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;">
														<?php echo esc_html( $acss_icon_message ); ?>
												</span>
											</div>
										</div>
										<div style='clear:both'></div>
										<?php
									}
									
								}

								if ('image' === $message_type) {
									if ($acss_image) {
										?>
											<div class="acss_image_div">
												<img class="acss_image" src="<?php echo esc_url( $acss_image ); ?> "/>
											</div>
										<?php 
									}
								}

								if ('date' === $message_type) {
									if ('yes' === $acss_enable_out_of_stock) {
										?>
										<div class="acss_date_div">
											<p class="acss_date" style="color:<?php echo esc_html( $acss_outstock_color ); ?>;font-size: <?php echo esc_html($acss_outstock_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
										</div>	
										<?php 
									} elseif ('yes' === $acss_back_orders) {
										?>
										<div class="acss_date_div">
											<p class="acss_date" style="color:<?php echo esc_html( $acss_backorder_color ); ?>;font-size: <?php echo esc_html($acss_backorder_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
										</div>	
										<?php 
									} else {
										?>
										<div class="acss_date_div">
											<p class="acss_date" style="color:<?php echo esc_html( $acss_instock_color ); ?>;font-size: <?php echo esc_html($acss_instock_font); ?>px;"><?php echo esc_html( $acss_date_message ); ?>&nbsp;<?php echo esc_html( $acss_date ); ?></p>
										</div>	
										<?php 
									}

								} 
								?>
						</li>	
								<?php 
							}
						}
						if ('yes' !== $show_multiple_status) {
							break;
						}
					} 
					?>
				</ul>
			</div>
				<?php
			
		}

		
		public function acss_get_stock_rules() {
			$args = array(
				'post_type'        => 'acss_rules',
				'post_status'      => 'publish',
				'numberposts'      => -1,
				'orderby'          => 'menu_order',
				'order'            => 'ASC',
				'suppress_filter'  =>  true,
			);
			return  get_posts( $args );

		}

		public function acss_get_sub_rules( $rule_id) {
			$args = array(
				'post_type'        => 'acss_sub_rules',
				'post_status'      => 'publish',
				'numberposts'      => -1,
				'orderby'          => 'menu_order',
				'order'            => 'ASC',
				'post_parent'      => $rule_id,
				'suppress_filter'  =>  true,
			);
			return get_posts($args);
		}

		public function acss_check_rules_for_product( $product_id, $rule_id) {
			$rulepriority            = get_post_meta( intval( $rule_id ), 'acss_value', true );
			$acss_user_roles         = (array) unserialize( get_post_meta( intval( $rule_id ), 'acss_userroles', true ) );
			$applied_on_all_products = get_post_meta( $rule_id, 'acss_product_enable', true );
			$acss_products           = (array) unserialize( get_post_meta( intval( $rule_id ), 'acss_products', true ) );
			$acss_products_cate      = (array) unserialize( get_post_meta( intval( $rule_id ), 'acss_products_cate', true ) );
			

			if ( ! is_user_logged_in() ) {
				if ( !in_array( 'guest' , (array) $acss_user_roles, true ) ) {

					return false;
				}

			} else {

				if ( is_user_logged_in() ) {

					$curr_user      = wp_get_current_user();
					$curr_user_role = current( $curr_user->roles );

					if ( !in_array( $curr_user_role, (array) $acss_user_roles, true ) ) {
						return false;
					}
				}
			}


			if ( 'yes' === $applied_on_all_products ) {
				return true;
			}

			if ( in_array( $product_id, $acss_products ) ) {
				return true;
			}
			if (!empty ($acss_products_cate)) {
				foreach ( $acss_products_cate as $cat ) {

					if ( !empty( $cat) && has_term( $cat, 'product_cat', $product_id ) ) {

						return true;
					}
				}
			}

			return false;
		}

		public function acss_check_stock_for_product( $stock_amount, $lower_limit = 0.0, $upper_limit = 0.0 ) {
			$flag = false;
			if ( 0.0 === floatval( $lower_limit ) && 0.0 === floatval( $upper_limit ) ) {
				$flag = true;
			} else {
				if ( 0.0 === floatval( $lower_limit ) && $stock_amount <= floatval( $upper_limit ) ) {
					$flag = true;
				} elseif ( 0.0 === floatval( $upper_limit ) && $stock_amount >= $lower_limit ) {
					$flag = true;
				} elseif ( $lower_limit <= $stock_amount && $stock_amount <= $upper_limit ) {
					$flag = true;
				}
			}
			return $flag;
		}
 
	}
	new Class_Front_Addify_Css();
}
